summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAntoine Eiche <lewo@abesis.fr>2021-05-01 08:21:27 +0200
committerAntoine Eiche <lewo@abesis.fr>2021-05-01 08:21:27 +0200
commit8b287056215cac91438a671054e7eb2c932ab21a (patch)
tree137f1705bcb0cc510cb66f7bdd473b45a612ac04
parent5248dce1eabc7505d4023ca86ba2dd0a5a3eaf6f (diff)
Rename intern/extern tests to internal/externalrename-tests
-rw-r--r--docs/howto-develop.rst4
-rw-r--r--tests/default.nix12
-rw-r--r--tests/external.nix (renamed from tests/extern.nix)2
-rw-r--r--tests/internal.nix (renamed from tests/intern.nix)2
4 files changed, 10 insertions, 10 deletions
diff --git a/docs/howto-develop.rst b/docs/howto-develop.rst
index 83e2168..57afee3 100644
--- a/docs/howto-develop.rst
+++ b/docs/howto-develop.rst
@@ -13,8 +13,8 @@ You can run the testsuite via
::
- $ nix-build tests -A extern.nixpkgs_20_03
- $ nix-build tests -A intern.nixpkgs_unstable
+ $ nix-build tests -A external.nixpkgs_20_03
+ $ nix-build tests -A internal.nixpkgs_unstable
...
Contributing to the documentation
diff --git a/tests/extern.nix b/tests/external.nix
index 9c7d5c1..f453608 100644
--- a/tests/extern.nix
+++ b/tests/external.nix
@@ -17,7 +17,7 @@
{ pkgs ? import <nixpkgs> {}}:
pkgs.nixosTest {
- name = "extern";
+ name = "external";
nodes = {
server = { config, pkgs, ... }:
{
diff --git a/tests/intern.nix b/tests/internal.nix
index b357ed9..12590c0 100644
--- a/tests/intern.nix
+++ b/tests/internal.nix
@@ -37,7 +37,7 @@ let
passwordFile = pkgs.writeText "password" "my-password";
in
pkgs.nixosTest {
- name = "intern";
+ name = "internal";
nodes = {
machine = { config, pkgs, ... }: {
imports = [
diff --git a/tests/default.nix b/tests/default.nix
index 6ebea89..10aba18 100644
--- a/tests/default.nix
+++ b/tests/default.nix
@@ -1,9 +1,9 @@
# Generate an attribute sets containing all tests for all releaeses
# It looks like:
# - extern.nixpkgs_20.03
# - extern.nixpkgs_unstable
# - intern.nixpkgs_20.03
# - intern.nixpkgs_unstable
with builtins;
@@ -32,8 +32,8 @@ let
];
testNames = [
- "intern"
- "extern"
+ "internal"
+ "external"
"clamav"
"multiple"
];
@@ -1,9 +1,9 @@
# Generate an attribute sets containing all tests for all releaeses
# It looks like:
-# - extern.nixpkgs_20.03
-# - extern.nixpkgs_unstable
-# - intern.nixpkgs_20.03
-# - intern.nixpkgs_unstable
+# - external.nixpkgs_20.03
+# - external.nixpkgs_unstable
+# - internal.nixpkgs_20.03
+# - internal.nixpkgs_unstable
with builtins;